@@ -94,13 +94,18 @@ class EXMLTestResult(TextTestResult):
                                      getattr(test, 'description', 'UNKNOWN')))
         return testcase
 
+    def _restoreStdout(self):
+        '''Disables buffering once the stdout/stderr are reset.'''
+        super(EXMLTestResult, self)._restoreStdout()
+        self.buffer = False
+
     def _add_tb_to_test(self, test, test_result, err):
         '''Add a traceback to the test result element'''
         exc_class, exc_value, tb = err
         tb_str = self._exc_info_to_string(err, test)
         test_result.set('type', '%s.%s' % (exc_class.__module__, exc_class.__name__))
         test_result.set('message', smart_text(exc_value))
-        test_result.text = tb_str
+        test_result.text = smart_text(tb_str)
 
     def dump_xml(self, output_dir):
         """
