@@ -19,3 +19,15 @@ def static_files_iterator(tested_locations, extension, ignore_patterns=None, add
     return (path for path in source
             if path.endswith(extension)
             if any(path.startswith(location) for location in tested_locations))
+
+
+def set_option(conf_dict, opt_name, opt_value, conf_file, default=None, split=None):
+    if conf_file is None:
+        if opt_value is None:
+            opt_value = default
+
+    if opt_value:
+        if split:
+            opt_value = opt_value.split(split)
+
+        conf_dict[opt_name] = opt_value
