@@ -3,6 +3,7 @@ import os
 import codecs
 import subprocess
 from optparse import make_option
+from django.conf import settings
 from django_jenkins.tasks import static_files_iterator
 
 
@@ -17,7 +18,7 @@ class Reporter(object):
         output = codecs.open(os.path.join(options['output_dir'], 'jshint.xml'), 'w', 'utf-8')
 
         files = list(
-            static_files_iterator(apps_locations,
+            static_files_iterator(apps_locations + list(getattr(settings, 'STATICFILES_DIRS', [])),
                                   extension='.js',
                                   ignore_patterns=options['jshint_exclude'].split(',')))
 
