@@ -40,16 +40,26 @@ JENKINS_TASKS = (
     'django_jenkins.tasks.run_pylint',
     'django_jenkins.tasks.run_pep8',
     'django_jenkins.tasks.run_csslint',
+    'django_jenkins.tasks.run_scsslint',
     'django_jenkins.tasks.run_flake8',
     'django_jenkins.tasks.run_pyflakes',
     'django_jenkins.tasks.run_jshint',
     'django_jenkins.tasks.run_sloccount',
 )
 
+COVERAGE_EXCLUDES = ['tests.test_app.not_for_coverage', ]
+COVERAGE_EXCLUDES_FOLDERS = [os.path.join(PROJECT_ROOT, 'test_app_dirs/not_for_coverage/'), ]
 
-JSHINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/js/test.js')]
-CSSLINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/css/test.css')]
+# JSHINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/js/test.js')]
+# CSSLINT_CHECKED_FILES = [os.path.join(PROJECT_ROOT, 'static/css/test.css')]
 
+PYLINT_LOAD_PLUGIN = (
+    'pylint_django',
+)
+
+STATICFILES_DIRS = [
+    os.path.join(PROJECT_ROOT, 'static/'),
+]
 
 STATIC_URL = '/media/'
 
